==> kite-1.0b3.tar.gz: kite-1.0b3/modules/System/network/wrapper.kt <==
##############################################################################
# Copyright (c) 2007, Mooneer Salem
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the Kite Language organization nor the
#       names of its contributors may be used to endorse or promote products
#       derived from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY MOONEER SALEM ``AS IS'' AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL MOONEER SALEM BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
##############################################################################

import "System.network.socket";

class TcpSocket from System.network.socket [
    ##########################################################################
    # Class constructor.
    ##########################################################################
    construct (bind_host, bind_port) [
        base|__construct__(System.network.socket.AF_INET,
                           System.network.socket.SOCK_STREAM,
                           0);
        this|bind(bind_host, bind_port);
    ],

    ##########################################################################
    # Class constructor.
    ##########################################################################
    construct () [
        base|__construct__(System.network.socket.AF_INET,
                           System.network.socket.SOCK_STREAM,
                           0);
    ]
];

class UdpSocket from System.network.socket [
    ##########################################################################
    # Class constructor.
    ##########################################################################
    construct (bind_host, bind_port) [
        base|__construct__(System.network.socket.AF_INET,
                           System.network.socket.SOCK_DGRAM,
                           0);
        this|bind(bind_host, bind_port);
    ],

    ##########################################################################
    # Class constructor.
    ##########################################################################
    construct () [
        base|__construct__(System.network.socket.AF_INET,
                           System.network.socket.SOCK_DGRAM,
                           0);
    ]
];

==> kite_1.0.2.orig.tar.gz: kite-1.0.2/modules/System/network/wrapper.kt <==
##############################################################################
# Copyright (c) 2007, Mooneer Salem
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the Kite Language organization nor the
#       names of its contributors may be used to endorse or promote products
#       derived from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY MOONEER SALEM ``AS IS'' AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL MOONEER SALEM BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
##############################################################################

/[Wrapper classes to the socket library.]/

import "System.network.socket";

class TcpSocket from System.network.socket 
    /[TCP socket class wrapper.]/
[
    construct (
        bind_host /[Host to bind to.]/, 
        bind_port /[Port to bind to.]/
    )   /[Class constructor.]/ 
    [
        base|__construct__(System.network.socket.AF_INET,
                           System.network.socket.SOCK_STREAM,
                           0);
        this|bind(bind_host, bind_port);
    ],

    construct () 
        /[Class constructor.]/
    [
        base|__construct__(System.network.socket.AF_INET,
                           System.network.socket.SOCK_STREAM,
                           0);
    ]
];

class UdpSocket from System.network.socket 
    /[UDP socket class wrapper.]/
[
    construct (
        bind_host /[Host to bind to.]/, 
        bind_port /[Port to bind to.]/
    )   /[Class constructor.]/
    [
        base|__construct__(System.network.socket.AF_INET,
                           System.network.socket.SOCK_DGRAM,
                           0);
        this|bind(bind_host, bind_port);
    ],

    construct () 
        /[Class constructor.]/
    [
        base|__construct__(System.network.socket.AF_INET,
                           System.network.socket.SOCK_DGRAM,
                           0);
    ]
];
